From 8bf516263c6582771e7576e8484ca8cfaa8cb9cb Mon Sep 17 00:00:00 2001
From: Cheng-Han, Wu
Date: Wed, 20 Apr 2016 18:11:40 +0800
Subject: Update CodeMirror to 5.13.5
---
public/vendor/codemirror/mode/clike/clike.js | 87 +++--
public/vendor/codemirror/mode/clojure/clojure.js | 9 +-
public/vendor/codemirror/mode/crystal/crystal.js | 2 +-
public/vendor/codemirror/mode/dart/dart.js | 27 ++
public/vendor/codemirror/mode/django/django.js | 23 +-
public/vendor/codemirror/mode/dtd/dtd.js | 12 +-
public/vendor/codemirror/mode/dylan/dylan.js | 85 ++++-
public/vendor/codemirror/mode/dylan/test.js | 88 +++++
public/vendor/codemirror/mode/fcl/fcl.js | 173 +++++++++
public/vendor/codemirror/mode/fcl/index.html | 108 ++++++
public/vendor/codemirror/mode/gfm/index.html | 2 +-
public/vendor/codemirror/mode/gfm/test.js | 6 +
public/vendor/codemirror/mode/haml/haml.js | 2 +-
.../vendor/codemirror/mode/handlebars/index.html | 7 +-
.../mode/haskell-literate/haskell-literate.js | 2 +-
.../vendor/codemirror/mode/htmlembedded/index.html | 2 +-
.../vendor/codemirror/mode/htmlmixed/htmlmixed.js | 42 +--
public/vendor/codemirror/mode/index.html | 6 +
public/vendor/codemirror/mode/jsx/jsx.js | 6 +-
public/vendor/codemirror/mode/julia/julia.js | 150 ++++----
public/vendor/codemirror/mode/markdown/markdown.js | 4 +-
public/vendor/codemirror/mode/markdown/test.js | 18 +-
.../codemirror/mode/mathematica/mathematica.js | 1 +
public/vendor/codemirror/mode/meta.js | 21 +-
public/vendor/codemirror/mode/octave/index.html | 2 +-
public/vendor/codemirror/mode/pegjs/pegjs.js | 10 +-
public/vendor/codemirror/mode/perl/perl.js | 2 +-
.../vendor/codemirror/mode/powershell/index.html | 204 +++++++++++
.../codemirror/mode/powershell/powershell.js | 396 +++++++++++++++++++++
public/vendor/codemirror/mode/powershell/test.js | 72 ++++
.../codemirror/mode/properties/properties.js | 2 +-
public/vendor/codemirror/mode/protobuf/index.html | 64 ++++
public/vendor/codemirror/mode/protobuf/protobuf.js | 68 ++++
public/vendor/codemirror/mode/puppet/puppet.js | 2 +-
public/vendor/codemirror/mode/python/index.html | 2 +-
public/vendor/codemirror/mode/python/python.js | 63 ++--
public/vendor/codemirror/mode/r/r.js | 2 +
public/vendor/codemirror/mode/sas/index.html | 81 +++++
public/vendor/codemirror/mode/sas/sas.js | 315 ++++++++++++++++
public/vendor/codemirror/mode/sparql/sparql.js | 8 +-
.../codemirror/mode/spreadsheet/spreadsheet.js | 5 +-
public/vendor/codemirror/mode/sql/index.html | 4 +-
public/vendor/codemirror/mode/sql/sql.js | 28 +-
public/vendor/codemirror/mode/swift/swift.js | 47 ++-
public/vendor/codemirror/mode/tcl/tcl.js | 32 +-
.../codemirror/mode/tiddlywiki/tiddlywiki.js | 206 ++++-------
public/vendor/codemirror/mode/troff/troff.js | 4 +-
public/vendor/codemirror/mode/twig/twig.js | 15 +-
public/vendor/codemirror/mode/velocity/index.html | 2 +
public/vendor/codemirror/mode/velocity/velocity.js | 2 +-
public/vendor/codemirror/mode/verilog/index.html | 2 +-
public/vendor/codemirror/mode/verilog/test.js | 2 +-
public/vendor/codemirror/mode/verilog/verilog.js | 2 +-
public/vendor/codemirror/mode/vhdl/vhdl.js | 2 +-
public/vendor/codemirror/mode/webidl/index.html | 71 ++++
public/vendor/codemirror/mode/webidl/webidl.js | 195 ++++++++++
public/vendor/codemirror/mode/xml/index.html | 6 +-
public/vendor/codemirror/mode/xml/xml.js | 2 +-
public/vendor/codemirror/mode/xquery/xquery.js | 2 +-
public/vendor/codemirror/mode/yacas/index.html | 87 +++++
public/vendor/codemirror/mode/yacas/yacas.js | 138 +++++++
.../codemirror/mode/yaml-frontmatter/index.html | 2 +-
.../mode/yaml-frontmatter/yaml-frontmatter.js | 2 +-
63 files changed, 2642 insertions(+), 392 deletions(-)
create mode 100644 public/vendor/codemirror/mode/dylan/test.js
create mode 100644 public/vendor/codemirror/mode/fcl/fcl.js
create mode 100644 public/vendor/codemirror/mode/fcl/index.html
create mode 100644 public/vendor/codemirror/mode/powershell/index.html
create mode 100644 public/vendor/codemirror/mode/powershell/powershell.js
create mode 100644 public/vendor/codemirror/mode/powershell/test.js
create mode 100644 public/vendor/codemirror/mode/protobuf/index.html
create mode 100644 public/vendor/codemirror/mode/protobuf/protobuf.js
create mode 100644 public/vendor/codemirror/mode/sas/index.html
create mode 100755 public/vendor/codemirror/mode/sas/sas.js
create mode 100644 public/vendor/codemirror/mode/webidl/index.html
create mode 100644 public/vendor/codemirror/mode/webidl/webidl.js
create mode 100644 public/vendor/codemirror/mode/yacas/index.html
create mode 100644 public/vendor/codemirror/mode/yacas/yacas.js
(limited to 'public/vendor/codemirror/mode')
diff --git a/public/vendor/codemirror/mode/clike/clike.js b/public/vendor/codemirror/mode/clike/clike.js
index 4f5c0cf3..695d5cef 100644
--- a/public/vendor/codemirror/mode/clike/clike.js
+++ b/public/vendor/codemirror/mode/clike/clike.js
@@ -11,6 +11,42 @@
})(function(CodeMirror) {
"use strict";
+function Context(indented, column, type, align, prev) {
+ this.indented = indented;
+ this.column = column;
+ this.type = type;
+ this.align = align;
+ this.prev = prev;
+}
+function isStatement(type) {
+ return type == "statement" || type == "switchstatement" || type == "namespace";
+}
+function pushContext(state, col, type) {
+ var indent = state.indented;
+ if (state.context && isStatement(state.context.type) && !isStatement(type))
+ indent = state.context.indented;
+ return state.context = new Context(indent, col, type, null, state.context);
+}
+function popContext(state) {
+ var t = state.context.type;
+ if (t == ")" || t == "]" || t == "}")
+ state.indented = state.context.indented;
+ return state.context = state.context.prev;
+}
+
+function typeBefore(stream, state) {
+ if (state.prevToken == "variable" || state.prevToken == "variable-3") return true;
+ if (/\S(?:[^- ]>|[*\]])\s*$|\*$/.test(stream.string.slice(0, stream.start))) return true;
+}
+
+function isTopScope(context) {
+ for (;;) {
+ if (!context || context.type == "top") return true;
+ if (context.type == "}" && context.prev.type != "namespace") return false;
+ context = context.prev;
+ }
+}
+
CodeMirror.defineMode("clike", function(config, parserConfig) {
var indentUnit = config.indentUnit,
statementIndentUnit = parserConfig.statementIndentUnit || indentUnit,
@@ -64,7 +100,7 @@ CodeMirror.defineMode("clike", function(config, parserConfig) {
}
}
if (isOperatorChar.test(ch)) {
- stream.eatWhile(isOperatorChar);
+ while (!stream.match(/^\/[\/*]/, false) && stream.eat(isOperatorChar)) {}
return "operator";
}
stream.eatWhile(/[\w\$_\xa1-\uffff]/);
@@ -111,42 +147,6 @@ CodeMirror.defineMode("clike", function(config, parserConfig) {
return "comment";
}
- function Context(indented, column, type, align, prev) {
- this.indented = indented;
- this.column = column;
- this.type = type;
- this.align = align;
- this.prev = prev;
- }
- function isStatement(type) {
- return type == "statement" || type == "switchstatement" || type == "namespace";
- }
- function pushContext(state, col, type) {
- var indent = state.indented;
- if (state.context && isStatement(state.context.type) && !isStatement(type))
- indent = state.context.indented;
- return state.context = new Context(indent, col, type, null, state.context);
- }
- function popContext(state) {
- var t = state.context.type;
- if (t == ")" || t == "]" || t == "}")
- state.indented = state.context.indented;
- return state.context = state.context.prev;
- }
-
- function typeBefore(stream, state) {
- if (state.prevToken == "variable" || state.prevToken == "variable-3") return true;
- if (/\S(?:[^- ]>|[*\]])\s*$|\*$/.test(stream.string.slice(0, stream.start))) return true;
- }
-
- function isTopScope(context) {
- for (;;) {
- if (!context || context.type == "top") return true;
- if (context.type == "}" && context.prev.type != "namespace") return false;
- context = context.prev;
- }
- }
-
// Interface
return {
@@ -497,7 +497,7 @@ CodeMirror.defineMode("clike", function(config, parserConfig) {
),
types: words(
"AnyVal App Application Array BufferedIterator BigDecimal BigInt Char Console Either " +
- "Enumeration Equiv Error Exception Fractional Function IndexedSeq Integral Iterable " +
+ "Enumeration Equiv Error Exception Fractional Function IndexedSeq Int Integral Iterable " +
"Iterator List Map Numeric Nil NotNull Option Ordered Ordering PartialFunction PartialOrdering " +
"Product Proxy Range Responder Seq Serializable Set Specializable Stream StringBuilder " +
"StringContext Symbol Throwable Traversable TraversableOnce Tuple Unit Vector " +
@@ -527,6 +527,15 @@ CodeMirror.defineMode("clike", function(config, parserConfig) {
"'": function(stream) {
stream.eatWhile(/[\w\$_\xa1-\uffff]/);
return "atom";
+ },
+ "=": function(stream, state) {
+ var cx = state.context
+ if (cx.type == "}" && cx.align && stream.eat(">")) {
+ state.context = new Context(cx.indented, cx.column, cx.type, null, cx.prev)
+ return "operator"
+ } else {
+ return false
+ }
}
},
modeProps: {closeBrackets: {triples: '"'}}
@@ -658,7 +667,7 @@ CodeMirror.defineMode("clike", function(config, parserConfig) {
def("text/x-objectivec", {
name: "clike",
- keywords: words(cKeywords + "inline restrict _Bool _Complex _Imaginery BOOL Class bycopy byref id IMP in " +
+ keywords: words(cKeywords + "inline restrict _Bool _Complex _Imaginary BOOL Class bycopy byref id IMP in " +
"inout nil oneway out Protocol SEL self super atomic nonatomic retain copy readwrite readonly"),
types: words(cTypes),
atoms: words("YES NO NULL NILL ON OFF true false"),
diff --git a/public/vendor/codemirror/mode/clojure/clojure.js b/public/vendor/codemirror/mode/clojure/clojure.js
index 44948d04..cd8129f7 100644
--- a/public/vendor/codemirror/mode/clojure/clojure.js
+++ b/public/vendor/codemirror/mode/clojure/clojure.js
@@ -59,7 +59,8 @@ CodeMirror.defineMode("clojure", function (options) {
sign: /[+-]/,
exponent: /e/i,
keyword_char: /[^\s\(\[\;\)\]]/,
- symbol: /[\w*+!\-\._?:<>\/\xa1-\uffff]/
+ symbol: /[\w*+!\-\._?:<>\/\xa1-\uffff]/,
+ block_indent: /^(?:def|with)[^\/]+$|\/(?:def|with)/
};
function stateStack(indent, type, prev) { // represents a state stack object
@@ -142,7 +143,7 @@ CodeMirror.defineMode("clojure", function (options) {
}
// skip spaces
- if (stream.eatSpace()) {
+ if (state.mode != "string" && stream.eatSpace()) {
return null;
}
var returnType = null;
@@ -190,7 +191,7 @@ CodeMirror.defineMode("clojure", function (options) {
}
if (keyWord.length > 0 && (indentKeys.propertyIsEnumerable(keyWord) ||
- /^(?:def|with)/.test(keyWord))) { // indent-word
+ tests.block_indent.test(keyWord))) { // indent-word
pushStack(state, indentTemp + INDENT_WORD_SKIP, ch);
} else { // non-indent word
// we continue eating the spaces
@@ -243,5 +244,7 @@ CodeMirror.defineMode("clojure", function (options) {
});
CodeMirror.defineMIME("text/x-clojure", "clojure");
+CodeMirror.defineMIME("text/x-clojurescript", "clojure");
+CodeMirror.defineMIME("application/edn", "clojure");
});
diff --git a/public/vendor/codemirror/mode/crystal/crystal.js b/public/vendor/codemirror/mode/crystal/crystal.js
index 2e74bee4..e63627ce 100644
--- a/public/vendor/codemirror/mode/crystal/crystal.js
+++ b/public/vendor/codemirror/mode/crystal/crystal.js
@@ -209,7 +209,7 @@
// Operators
if (stream.match(operators)) {
- stream.eat("="); // Operators can follow assigin symbol.
+ stream.eat("="); // Operators can follow assign symbol.
return "operator";
}
diff --git a/public/vendor/codemirror/mode/dart/dart.js b/public/vendor/codemirror/mode/dart/dart.js
index d92eb519..8d383a95 100644
--- a/public/vendor/codemirror/mode/dart/dart.js
+++ b/public/vendor/codemirror/mode/dart/dart.js
@@ -72,6 +72,12 @@
return null;
}
return false;
+ },
+
+ "/": function(stream, state) {
+ if (!stream.eat("*")) return false
+ state.tokenize = tokenNestedComment(1)
+ return state.tokenize(stream, state)
}
}
});
@@ -121,6 +127,27 @@
return "variable";
}
+ function tokenNestedComment(depth) {
+ return function (stream, state) {
+ var ch
+ while (ch = stream.next()) {
+ if (ch == "*" && stream.eat("/")) {
+ if (depth == 1) {
+ state.tokenize = null
+ break
+ } else {
+ state.tokenize = tokenNestedComment(depth - 1)
+ return state.tokenize(stream, state)
+ }
+ } else if (ch == "/" && stream.eat("*")) {
+ state.tokenize = tokenNestedComment(depth + 1)
+ return state.tokenize(stream, state)
+ }
+ }
+ return "comment"
+ }
+ }
+
CodeMirror.registerHelper("hintWords", "application/dart", keywords.concat(atoms).concat(builtins));
// This is needed to make loading through meta.js work.
diff --git a/public/vendor/codemirror/mode/dtd/dtd.js b/public/vendor/codemirror/mode/dtd/dtd.js
index f37029a7..52d76ee1 100644
--- a/public/vendor/codemirror/mode/dtd/dtd.js
+++ b/public/vendor/codemirror/mode/dtd/dtd.js
@@ -114,17 +114,17 @@ CodeMirror.defineMode("dtd", function(config) {
if( textAfter.match(/\]\s+|\]/) )n=n-1;
else if(textAfter.substr(textAfter.length-1, textAfter.length) === ">"){
- if(textAfter.substr(0,1) === "<")n;
- else if( type == "doindent" && textAfter.length > 1 )n;
+ if(textAfter.substr(0,1) === "<") {}
+ else if( type == "doindent" && textAfter.length > 1 ) {}
else if( type == "doindent")n--;
- else if( type == ">" && textAfter.length > 1)n;
- else if( type == "tag" && textAfter !== ">")n;
+ else if( type == ">" && textAfter.length > 1) {}
+ else if( type == "tag" && textAfter !== ">") {}
else if( type == "tag" && state.stack[state.stack.length-1] == "rule")n--;
else if( type == "tag")n++;
else if( textAfter === ">" && state.stack[state.stack.length-1] == "rule" && type === ">")n--;
- else if( textAfter === ">" && state.stack[state.stack.length-1] == "rule")n;
+ else if( textAfter === ">" && state.stack[state.stack.length-1] == "rule") {}
else if( textAfter.substr(0,1) !== "<" && textAfter.substr(0,1) === ">" )n=n-1;
- else if( textAfter === ">")n;
+ else if( textAfter === ">") {}
else n=n-1;
//over rule them all
if(type == null || type == "]")n--;
diff --git a/public/vendor/codemirror/mode/dylan/dylan.js b/public/vendor/codemirror/mode/dylan/dylan.js
index 85f0166c..1b46bc82 100644
--- a/public/vendor/codemirror/mode/dylan/dylan.js
+++ b/public/vendor/codemirror/mode/dylan/dylan.js
@@ -169,15 +169,16 @@ CodeMirror.defineMode("dylan", function(_config) {
} else if (stream.eat("/")) {
stream.skipToEnd();
return "comment";
- } else {
- stream.skipTo(" ");
- return "operator";
}
+ stream.backUp(1);
}
// Decimal
- else if (/\d/.test(ch)) {
- stream.match(/^\d*(?:\.\d*)?(?:e[+\-]?\d+)?/);
- return "number";
+ else if (/[+\-\d\.]/.test(ch)) {
+ if (stream.match(/^[+-]?[0-9]*\.[0-9]*([esdx][+-]?[0-9]+)?/i) ||
+ stream.match(/^[+-]?[0-9]+([esdx][+-]?[0-9]+)/i) ||
+ stream.match(/^[+-]?\d+/)) {
+ return "number";
+ }
}
// Hash
else if (ch == "#") {
@@ -186,7 +187,7 @@ CodeMirror.defineMode("dylan", function(_config) {
ch = stream.peek();
if (ch == '"') {
stream.next();
- return chain(stream, state, tokenString('"', "string-2"));
+ return chain(stream, state, tokenString('"', "string"));
}
// Binary number
else if (ch == "b") {
@@ -206,11 +207,51 @@ CodeMirror.defineMode("dylan", function(_config) {
stream.eatWhile(/[0-7]/);
return "number";
}
+ // Token concatenation in macros
+ else if (ch == '#') {
+ stream.next();
+ return "punctuation";
+ }
+ // Sequence literals
+ else if ((ch == '[') || (ch == '(')) {
+ stream.next();
+ return "bracket";
// Hash symbol
- else {
+ } else if (stream.match(/f|t|all-keys|include|key|next|rest/i)) {
+ return "atom";
+ } else {
stream.eatWhile(/[-a-zA-Z]/);
- return "keyword";
+ return "error";
+ }
+ } else if (ch == "~") {
+ stream.next();
+ ch = stream.peek();
+ if (ch == "=") {
+ stream.next();
+ ch = stream.peek();
+ if (ch == "=") {
+ stream.next();
+ return "operator";
+ }
+ return "operator";
}
+ return "operator";
+ } else if (ch == ":") {
+ stream.next();
+ ch = stream.peek();
+ if (ch == "=") {
+ stream.next();
+ return "operator";
+ } else if (ch == ":") {
+ stream.next();
+ return "punctuation";
+ }
+ } else if ("[](){}".indexOf(ch) != -1) {
+ stream.next();
+ return "bracket";
+ } else if (".,".indexOf(ch) != -1) {
+ stream.next();
+ return "punctuation";
} else if (stream.match("end")) {
return "keyword";
}
@@ -223,6 +264,10 @@ CodeMirror.defineMode("dylan", function(_config) {
return patternStyles[name];
}
}
+ if (/[+\-*\/^=<>&|]/.test(ch)) {
+ stream.next();
+ return "operator";
+ }
if (stream.match("define")) {
return "def";
} else {
@@ -240,29 +285,37 @@ CodeMirror.defineMode("dylan", function(_config) {
}
function tokenComment(stream, state) {
- var maybeEnd = false,
- ch;
+ var maybeEnd = false, maybeNested = false, nestedCount = 0, ch;
while ((ch = stream.next())) {
if (ch == "/" && maybeEnd) {
- state.tokenize = tokenBase;
- break;
+ if (nestedCount > 0) {
+ nestedCount--;
+ } else {
+ state.tokenize = tokenBase;
+ break;
+ }
+ } else if (ch == "*" && maybeNested) {
+ nestedCount++;
}
maybeEnd = (ch == "*");
+ maybeNested = (ch == "/");
}
return "comment";
}
function tokenString(quote, style) {
return function(stream, state) {
- var next, end = false;
+ var escaped = false, next, end = false;
while ((next = stream.next()) != null) {
- if (next == quote) {
+ if (next == quote && !escaped) {
end = true;
break;
}
+ escaped = !escaped && next == "\\";
}
- if (end)
+ if (end || !escaped) {
state.tokenize = tokenBase;
+ }
return style;
};
}
diff --git a/public/vendor/codemirror/mode/dylan/test.js b/public/vendor/codemirror/mode/dylan/test.js
new file mode 100644
index 00000000..bf25be27
--- /dev/null
+++ b/public/vendor/codemirror/mode/dylan/test.js
@@ -0,0 +1,88 @@
+// CodeMirror, copyright (c) by Marijn Haverbeke and others
+// Distributed under an MIT license: http://codemirror.net/LICENSE
+
+(function() {
+ var mode = CodeMirror.getMode({indentUnit: 2}, "dylan");
+ function MT(name) { test.mode(name, mode, Array.prototype.slice.call(arguments, 1)); }
+
+ MT('comments',
+ '[comment // This is a line comment]',
+ '[comment /* This is a block comment */]',
+ '[comment /* This is a multi]',
+ '[comment line comment]',
+ '[comment */]',
+ '[comment /* And this is a /*]',
+ '[comment /* nested */ comment */]');
+
+ MT('unary_operators',
+ '[operator -][variable a]',
+ '[operator -] [variable a]',
+ '[operator ~][variable a]',
+ '[operator ~] [variable a]');
+
+ MT('binary_operators',
+ '[variable a] [operator +] [variable b]',
+ '[variable a] [operator -] [variable b]',
+ '[variable a] [operator *] [variable b]',
+ '[variable a] [operator /] [variable b]',
+ '[variable a] [operator ^] [variable b]',
+ '[variable a] [operator =] [variable b]',
+ '[variable a] [operator ==] [variable b]',
+ '[variable a] [operator ~=] [variable b]',
+ '[variable a] [operator ~==] [variable b]',
+ '[variable a] [operator <] [variable b]',
+ '[variable a] [operator <=] [variable b]',
+ '[variable a] [operator >] [variable b]',
+ '[variable a] [operator >=] [variable b]',
+ '[variable a] [operator &] [variable b]',
+ '[variable a] [operator |] [variable b]',
+ '[variable a] [operator :=] [variable b]');
+
+ MT('integers',
+ '[number 1]',
+ '[number 123]',
+ '[number -123]',
+ '[number +456]',
+ '[number #b010]',
+ '[number #o073]',
+ '[number #xabcDEF123]');
+
+ MT('floats',
+ '[number .3]',
+ '[number -1.]',
+ '[number -2.335]',
+ '[number +3.78d1]',
+ '[number 3.78s-1]',
+ '[number -3.32e+5]');
+
+ MT('characters_and_strings',
+ "[string 'a']",
+ "[string '\\\\'']",
+ '[string ""]',
+ '[string "a"]',
+ '[string "abc def"]',
+ '[string "More escaped characters: \\\\\\\\ \\\\a \\\\b \\\\e \\\\f \\\\n \\\\r \\\\t \\\\0 ..."]');
+
+ MT('brackets',
+ '[bracket #[[]]]',
+ '[bracket #()]',
+ '[bracket #(][number 1][bracket )]',
+ '[bracket [[][number 1][punctuation ,] [number 3][bracket ]]]',
+ '[bracket ()]',
+ '[bracket {}]',
+ '[keyword if] [bracket (][variable foo][bracket )]',
+ '[bracket (][number 1][bracket )]',
+ '[bracket [[][number 1][bracket ]]]');
+
+ MT('hash_words',
+ '[punctuation ##]',
+ '[atom #f]', '[atom #F]',
+ '[atom #t]', '[atom #T]',
+ '[atom #all-keys]',
+ '[atom #include]',
+ '[atom #key]',
+ '[atom #next]',
+ '[atom #rest]',
+ '[string #"foo"]',
+ '[error #invalid]');
+})();
diff --git a/public/vendor/codemirror/mode/fcl/fcl.js b/public/vendor/codemirror/mode/fcl/fcl.js
new file mode 100644
index 00000000..51811697
--- /dev/null
+++ b/public/vendor/codemirror/mode/fcl/fcl.js
@@ -0,0 +1,173 @@
+// CodeMirror, copyright (c) by Marijn Haverbeke and others
+// Distributed under an MIT license: http://codemirror.net/LICENSE
+
+(function(mod) {
+ if (typeof exports == "object" && typeof module == "object") // CommonJS
+ mod(require("../../lib/codemirror"));
+ else if (typeof define == "function" && define.amd) // AMD
+ define(["../../lib/codemirror"], mod);
+ else // Plain browser env
+ mod(CodeMirror);
+})(function(CodeMirror) {
+"use strict";
+
+CodeMirror.defineMode("fcl", function(config) {
+ var indentUnit = config.indentUnit;
+
+ var keywords = {
+ "term": true,
+ "method": true, "accu": true,
+ "rule": true, "then": true, "is": true, "and": true, "or": true,
+ "if": true, "default": true
+ };
+
+ var start_blocks = {
+ "var_input": true,
+ "var_output": true,
+ "fuzzify": true,
+ "defuzzify": true,
+ "function_block": true,
+ "ruleblock": true
+ };
+
+ var end_blocks = {
+ "end_ruleblock": true,
+ "end_defuzzify": true,
+ "end_function_block": true,
+ "end_fuzzify": true,
+ "end_var": true
+ };
+
+ var atoms = {
+ "true": true, "false": true, "nan": true,
+ "real": true, "min": true, "max": true, "cog": true, "cogs": true
+ };
+
+ var isOperatorChar = /[+\-*&^%:=<>!|\/]/;
+
+ function tokenBase(stream, state) {
+ var ch = stream.next();
+
+ if (/[\d\.]/.test(ch)) {
+ if (ch == ".") {
+ stream.match(/^[0-9]+([eE][\-+]?[0-9]+)?/);
+ } else if (ch == "0") {
+ stream.match(/^[xX][0-9a-fA-F]+/) || stream.match(/^0[0-7]+/);
+ } else {
+ stream.match(/^[0-9]*\.?[0-9]*([eE][\-+]?[0-9]+)?/);
+ }
+ return "number";
+ }
+
+ if (ch == "/" || ch == "(") {
+ if (stream.eat("*")) {
+ state.tokenize = tokenComment;
+ return tokenComment(stream, state);
+ }
+ if (stream.eat("/")) {
+ stream.skipToEnd();
+ return "comment";
+ }
+ }
+ if (isOperatorChar.test(ch)) {
+ stream.eatWhile(isOperatorChar);
+ return "operator";
+ }
+ stream.eatWhile(/[\w\$_\xa1-\uffff]/);
+
+ var cur = stream.current().toLowerCase();
+ if (keywords.propertyIsEnumerable(cur) ||
+ start_blocks.propertyIsEnumerable(cur) ||
+ end_blocks.propertyIsEnumerable(cur)) {
+ return "keyword";
+ }
+ if (atoms.propertyIsEnumerable(cur)) return "atom";
+ return "variable";
+ }
+
+
+ function tokenComment(stream, state) {
+ var maybeEnd = false, ch;
+ while (ch = stream.next()) {
+ if ((ch == "/" || ch == ")") && maybeEnd) {
+ state.tokenize = tokenBase;
+ break;
+ }
+ maybeEnd = (ch == "*");
+ }
+ return "comment";
+ }
+
+ function Context(indented, column, type, align, prev) {
+ this.indented = indented;
+ this.column = column;
+ this.type = type;
+ this.align = align;
+ this.prev = prev;
+ }
+
+ function pushContext(state, col, type) {
+ return state.context = new Context(state.indented, col, type, null, state.context);
+ }
+
+ function popContext(state) {
+ if (!state.context.prev) return;
+ var t = state.context.type;
+ if (t == "end_block")
+ state.indented = state.context.indented;
+ return state.context = state.context.prev;
+ }
+
+ // Interface
+
+ return {
+ startState: function(basecolumn) {
+ return {
+ tokenize: null,
+ context: new Context((basecolumn || 0) - indentUnit, 0, "top", false),
+ indented: 0,
+ startOfLine: true
+ };
+ },
+
+ token: function(stream, state) {
+ var ctx = state.context;
+ if (stream.sol()) {
+ if (ctx.align == null) ctx.align = false;
+ state.indented = stream.indentation();
+ state.startOfLine = true;
+ }
+ if (stream.eatSpace()) return null;
+
+ var style = (state.tokenize || tokenBase)(stream, state);
+ if (style == "comment") return style;
+ if (ctx.align == null) ctx.align = true;
+
+ var cur = stream.current().toLowerCase();
+
+ if (start_blocks.propertyIsEnumerable(cur)) pushContext(state, stream.column(), "end_block");
+ else if (end_blocks.propertyIsEnumerable(cur)) popContext(state);
+
+ state.startOfLine = false;
+ return style;
+ },
+
+ indent: function(state, textAfter) {
+ if (state.tokenize != tokenBase && state.tokenize != null) return 0;
+ var ctx = state.context;
+
+ var closing = end_blocks.propertyIsEnumerable(textAfter);
+ if (ctx.align) return ctx.column + (closing ? 0 : 1);
+ else return ctx.indented + (closing ? 0 : indentUnit);
+ },
+
+ electricChars: "ryk",
+ fold: "brace",
+ blockCommentStart: "(*",
+ blockCommentEnd: "*)",
+ lineComment: "//"
+ };
+});
+
+CodeMirror.defineMIME("text/x-fcl", "fcl");
+});
diff --git a/public/vendor/codemirror/mode/fcl/index.html b/public/vendor/codemirror/mode/fcl/index.html
new file mode 100644
index 00000000..3c18d0b3
--- /dev/null
+++ b/public/vendor/codemirror/mode/fcl/index.html
@@ -0,0 +1,108 @@
+
+
+
CodeMirror: FCL mode
+
+
+
+
+
+
+
+
+
+
+
+
+FCL mode
+
+
+
+
+ MIME type: text/x-fcl
+
diff --git a/public/vendor/codemirror/mode/gfm/index.html b/public/vendor/codemirror/mode/gfm/index.html
index 7e38c52d..24c90c06 100644
--- a/public/vendor/codemirror/mode/gfm/index.html
+++ b/public/vendor/codemirror/mode/gfm/index.html
@@ -47,7 +47,7 @@ Underscores_are_allowed_between_words.
GFM adds syntax to strikethrough text, which is missing from standard Markdown.
~~Mistaken text.~~
-~~**works with other fomatting**~~
+~~**works with other formatting**~~
~~spans across
lines~~
diff --git a/public/vendor/codemirror/mode/gfm/test.js b/public/vendor/codemirror/mode/gfm/test.js
index 0dcd3619..7a1a4ccf 100644
--- a/public/vendor/codemirror/mode/gfm/test.js
+++ b/public/vendor/codemirror/mode/gfm/test.js
@@ -51,6 +51,12 @@
"[comment ```]",
"bar");
+ MT("fencedCodeBlockModeSwitchingObjc",
+ "[comment ```objective-c]",
+ "[keyword @property] [variable NSString] [operator *] [variable foo];",
+ "[comment ```]",
+ "bar");
+
MT("fencedCodeBlocksNoTildes",
"~~~",
"foo",
diff --git a/public/vendor/codemirror/mode/haml/haml.js b/public/vendor/codemirror/mode/haml/haml.js
index 03ce8335..86def73e 100644
--- a/public/vendor/codemirror/mode/haml/haml.js
+++ b/public/vendor/codemirror/mode/haml/haml.js
@@ -11,7 +11,7 @@
})(function(CodeMirror) {
"use strict";
- // full haml mode. This handled embeded ruby and html fragments too
+ // full haml mode. This handled embedded ruby and html fragments too
CodeMirror.defineMode("haml", function(config) {
var htmlMode = CodeMirror.getMode(config, {name: "htmlmixed"});
var rubyMode = CodeMirror.getMode(config, "ruby");
diff --git a/public/vendor/codemirror/mode/handlebars/index.html b/public/vendor/codemirror/mode/handlebars/index.html
index 4f82d602..b1bfad1c 100644
--- a/public/vendor/codemirror/mode/handlebars/index.html
+++ b/public/vendor/codemirror/mode/handlebars/index.html
@@ -1,4 +1,4 @@
-
+
CodeMirror: Handlebars mode
@@ -71,4 +71,9 @@
Handlebars syntax highlighting for CodeMirror.
MIME types defined: text/x-handlebars-template
+
+ Supported options: base
to set the mode to
+ wrap. For example, use
+ mode: {name: "handlebars", base: "text/html"}
+ to highlight an HTML template.
diff --git a/public/vendor/codemirror/mode/haskell-literate/haskell-literate.js b/public/vendor/codemirror/mode/haskell-literate/haskell-literate.js
index 9358994d..906415b4 100644
--- a/public/vendor/codemirror/mode/haskell-literate/haskell-literate.js
+++ b/public/vendor/codemirror/mode/haskell-literate/haskell-literate.js
@@ -40,4 +40,4 @@
}, "haskell")
CodeMirror.defineMIME("text/x-literate-haskell", "haskell-literate")
-})
+});
diff --git a/public/vendor/codemirror/mode/htmlembedded/index.html b/public/vendor/codemirror/mode/htmlembedded/index.html
index 365ef8f3..f27582ef 100644
--- a/public/vendor/codemirror/mode/htmlembedded/index.html
+++ b/public/vendor/codemirror/mode/htmlembedded/index.html
@@ -52,7 +52,7 @@ This is an example of EJS (embedded javascript)
Mode for html embedded scripts like JSP and ASP.NET. Depends on HtmlMixed which in turn depends on
- JavaScript, CSS and XML. Other dependancies include those of the scriping language chosen.
+ JavaScript, CSS and XML. Other dependencies include those of the scripting language chosen.
MIME types defined: application/x-aspx
(ASP.NET),
application/x-ejs
(Embedded Javascript), application/x-jsp
(JavaServer Pages)
diff --git a/public/vendor/codemirror/mode/htmlmixed/htmlmixed.js b/public/vendor/codemirror/mode/htmlmixed/htmlmixed.js
index 21e74f16..6574fbd5 100644
--- a/public/vendor/codemirror/mode/htmlmixed/htmlmixed.js
+++ b/public/vendor/codemirror/mode/htmlmixed/htmlmixed.js
@@ -44,13 +44,9 @@
return attrRegexpCache[attr] = new RegExp("\\s+" + attr + "\\s*=\\s*('|\")?([^'\"]+)('|\")?\\s*");
}
- function getAttrValue(stream, attr) {
- var pos = stream.pos, match;
- while (pos >= 0 && stream.string.charAt(pos) !== "<") pos--;
- if (pos < 0) return pos;
- if (match = stream.string.slice(pos, stream.pos).match(getAttrRegexp(attr)))
- return match[2];
- return "";
+ function getAttrValue(text, attr) {
+ var match = text.match(getAttrRegexp(attr))
+ return match ? match[2] : ""
}
function getTagRegexp(tagName, anchored) {
@@ -66,10 +62,10 @@
}
}
- function findMatchingMode(tagInfo, stream) {
+ function findMatchingMode(tagInfo, tagText) {
for (var i = 0; i < tagInfo.length; i++) {
var spec = tagInfo[i];
- if (!spec[0] || spec[1].test(getAttrValue(stream, spec[0]))) return spec[2];
+ if (!spec[0] || spec[1].test(getAttrValue(tagText, spec[0]))) return spec[2];
}
}
@@ -89,15 +85,17 @@
tags.script.unshift(["type", configScript[i].matches, configScript[i].mode])
function html(stream, state) {
- var tagName = state.htmlState.tagName && state.htmlState.tagName.toLowerCase();
- var tagInfo = tagName && tags.hasOwnProperty(tagName) && tags[tagName];
-
- var style = htmlMode.token(stream, state.htmlState), modeSpec;
-
- if (tagInfo && /\btag\b/.test(style) && stream.current() === ">" &&
- (modeSpec = findMatchingMode(tagInfo, stream))) {
- var mode = CodeMirror.getMode(config, modeSpec);
- var endTagA = getTagRegexp(tagName, true), endTag = getTagRegexp(tagName, false);
+ var style = htmlMode.token(stream, state.htmlState), tag = /\btag\b/.test(style), tagName
+ if (tag && !/[<>\s\/]/.test(stream.current()) &&
+ (tagName = state.htmlState.tagName && state.htmlState.tagName.toLowerCase()) &&
+ tags.hasOwnProperty(tagName)) {
+ state.inTag = tagName + " "
+ } else if (state.inTag && tag && />$/.test(stream.current())) {
+ var inTag = /^([\S]+) (.*)/.exec(state.inTag)
+ state.inTag = null
+ var modeSpec = stream.current() == ">" && findMatchingMode(tags[inTag[1]], inTag[2])
+ var mode = CodeMirror.getMode(config, modeSpec)
+ var endTagA = getTagRegexp(inTag[1], true), endTag = getTagRegexp(inTag[1], false);
state.token = function (stream, state) {
if (stream.match(endTagA, false)) {
state.token = html;
@@ -108,6 +106,9 @@
};
state.localMode = mode;
state.localState = CodeMirror.startState(mode, htmlMode.indent(state.htmlState, ""));
+ } else if (state.inTag) {
+ state.inTag += stream.current()
+ if (stream.eol()) state.inTag += " "
}
return style;
};
@@ -115,7 +116,7 @@
return {
startState: function () {
var state = htmlMode.startState();
- return {token: html, localMode: null, localState: null, htmlState: state};
+ return {token: html, inTag: null, localMode: null, localState: null, htmlState: state};
},
copyState: function (state) {
@@ -123,7 +124,8 @@
if (state.localState) {
local = CodeMirror.copyState(state.localMode, state.localState);
}
- return {token: state.token, localMode: state.localMode, localState: local,
+ return {token: state.token, inTag: state.inTag,
+ localMode: state.localMode, localState: local,
htmlState: CodeMirror.copyState(htmlMode, state.htmlState)};
},
diff --git a/public/vendor/codemirror/mode/index.html b/public/vendor/codemirror/mode/index.html
index a6c293ec..be583159 100644
--- a/public/vendor/codemirror/mode/index.html
+++ b/public/vendor/codemirror/mode/index.html
@@ -59,6 +59,7 @@ option.
Elm
Erlang
Factor
+ FCL
Forth
Fortran
F#
@@ -102,7 +103,9 @@ option.
PGP (ASCII armor)
PHP
Pig Latin
+ PowerShell
Properties files
+ ProtoBuf
Puppet
Python
Q
@@ -111,6 +114,7 @@ option.
reStructuredText
Ruby
Rust
+ SAS
Sass
Spreadsheet
Scala
@@ -146,8 +150,10 @@ option.
Verilog/SystemVerilog
VHDL
Vue.js app
+ Web IDL
XML/HTML
XQuery
+ Yacas
YAML
YAML frontmatter
Z80
diff --git a/public/vendor/codemirror/mode/jsx/jsx.js b/public/vendor/codemirror/mode/jsx/jsx.js
index bc2ea797..aff01b8d 100644
--- a/public/vendor/codemirror/mode/jsx/jsx.js
+++ b/public/vendor/codemirror/mode/jsx/jsx.js
@@ -25,9 +25,9 @@
context.prev && copyContext(context.prev))
}
- CodeMirror.defineMode("jsx", function(config) {
+ CodeMirror.defineMode("jsx", function(config, modeConfig) {
var xmlMode = CodeMirror.getMode(config, {name: "xml", allowMissing: true, multilineTagIndentPastTag: false})
- var jsMode = CodeMirror.getMode(config, "javascript")
+ var jsMode = CodeMirror.getMode(config, modeConfig && modeConfig.base || "javascript")
function flatXMLIndent(state) {
var tagName = state.tagName
@@ -144,4 +144,4 @@
}, "xml", "javascript")
CodeMirror.defineMIME("text/jsx", "jsx")
-})
+});
diff --git a/public/vendor/codemirror/mode/julia/julia.js b/public/vendor/codemirror/mode/julia/julia.js
index 4471896b..004de443 100644
--- a/public/vendor/codemirror/mode/julia/julia.js
+++ b/public/vendor/codemirror/mode/julia/julia.js
@@ -14,27 +14,34 @@
CodeMirror.defineMode("julia", function(_conf, parserConf) {
var ERRORCLASS = 'error';
- function wordRegexp(words) {
- return new RegExp("^((" + words.join(")|(") + "))\\b");
+ function wordRegexp(words, end) {
+ if (typeof end === 'undefined') { end = "\\b"; }
+ return new RegExp("^((" + words.join(")|(") + "))" + end);
}
+ var octChar = "\\\\[0-7]{1,3}";
+ var hexChar = "\\\\x[A-Fa-f0-9]{1,2}";
+ var specialChar = "\\\\[abfnrtv0%?'\"\\\\]";
+ var singleChar = "([^\\u0027\\u005C\\uD800-\\uDFFF]|[\\uD800-\\uDFFF][\\uDC00-\\uDFFF])";
var operators = parserConf.operators || /^\.?[|&^\\%*+\-<>!=\/]=?|\?|~|:|\$|\.[<>]|<<=?|>>>?=?|\.[<>=]=|->?|\/\/|\bin\b(?!\()|[\u2208\u2209](?!\()/;
var delimiters = parserConf.delimiters || /^[;,()[\]{}]/;
- var identifiers = parserConf.identifiers || /^[_A-Za-z\u00A1-\uFFFF][_A-Za-z0-9\u00A1-\uFFFF]*!*/;
+ var identifiers = parserConf.identifiers || /^[_A-Za-z\u00A1-\uFFFF][\w\u00A1-\uFFFF]*!*/;
+ var charsList = [octChar, hexChar, specialChar, singleChar];
var blockOpeners = ["begin", "function", "type", "immutable", "let", "macro", "for", "while", "quote", "if", "else", "elseif", "try", "finally", "catch", "do"];
var blockClosers = ["end", "else", "elseif", "catch", "finally"];
var keywordList = ['if', 'else', 'elseif', 'while', 'for', 'begin', 'let', 'end', 'do', 'try', 'catch', 'finally', 'return', 'break', 'continue', 'global', 'local', 'const', 'export', 'import', 'importall', 'using', 'function', 'macro', 'module', 'baremodule', 'type', 'immutable', 'quote', 'typealias', 'abstract', 'bitstype'];
var builtinList = ['true', 'false', 'nothing', 'NaN', 'Inf'];
//var stringPrefixes = new RegExp("^[br]?('|\")")
- var stringPrefixes = /^(`|'|"{3}|([brv]?"))/;
+ var stringPrefixes = /^(`|"{3}|([brv]?"))/;
+ var chars = wordRegexp(charsList, "'");
var keywords = wordRegexp(keywordList);
var builtins = wordRegexp(builtinList);
var openers = wordRegexp(blockOpeners);
var closers = wordRegexp(blockClosers);
- var macro = /^@[_A-Za-z][_A-Za-z0-9]*/;
- var symbol = /^:[_A-Za-z\u00A1-\uFFFF][_A-Za-z0-9\u00A1-\uFFFF]*!*/;
- var typeAnnotation = /^::[^.,;"{()=$\s]+({[^}]*}+)*/;
+ var macro = /^@[_A-Za-z][\w]*/;
+ var symbol = /^:[_A-Za-z\u00A1-\uFFFF][\w\u00A1-\uFFFF]*!*/;
+ var typeAnnotation = /^::[^,;"{()=$\s]+({[^}]*}+)*/;
function inArray(state) {
var ch = currentScope(state);
@@ -53,19 +60,10 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
// tokenizers
function tokenBase(stream, state) {
- //Handle multiline comments
- if (stream.match(/^#=\s*/)) {
- state.scopes.push('#=');
- }
- if (currentScope(state) == '#=' && stream.match(/^=#/)) {
- state.scopes.pop();
- return 'comment';
- }
- if (state.scopes.indexOf('#=') >= 0) {
- if (!stream.match(/.*?(?=(#=|=#))/)) {
- stream.skipToEnd();
- }
- return 'comment';
+ // Handle multiline comments
+ if (stream.match(/^#=/, false)) {
+ state.tokenize = tokenComment;
+ return state.tokenize(stream, state);
}
// Handle scope changes
@@ -100,6 +98,10 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
state.scopes.push('[');
}
+ if (ch === '(') {
+ state.scopes.push('(');
+ }
+
var scope = currentScope(state);
if (scope == '[' && ch === ']') {
@@ -137,33 +139,20 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
// Handle Number Literals
if (stream.match(/^[0-9\.]/, false)) {
var imMatcher = RegExp(/^im\b/);
- var floatLiteral = false;
+ var numberLiteral = false;
// Floats
- if (stream.match(/^\d*\.(?!\.)\d+([ef][\+\-]?\d+)?/i)) { floatLiteral = true; }
- if (stream.match(/^\d+\.(?!\.)\d*/)) { floatLiteral = true; }
- if (stream.match(/^\.\d+/)) { floatLiteral = true; }
- if (stream.match(/^0x\.[0-9a-f]+p[\+\-]?\d+/i)) { floatLiteral = true; }
- if (floatLiteral) {
- // Float literals may be "imaginary"
- stream.match(imMatcher);
- state.leavingExpr = true;
- return 'number';
- }
+ if (stream.match(/^\d*\.(?!\.)\d*([Eef][\+\-]?\d+)?/i)) { numberLiteral = true; }
+ if (stream.match(/^\d+\.(?!\.)\d*/)) { numberLiteral = true; }
+ if (stream.match(/^\.\d+/)) { numberLiteral = true; }
+ if (stream.match(/^0x\.[0-9a-f]+p[\+\-]?\d+/i)) { numberLiteral = true; }
// Integers
- var intLiteral = false;
- // Hex
- if (stream.match(/^0x[0-9a-f]+/i)) { intLiteral = true; }
- // Binary
- if (stream.match(/^0b[01]+/i)) { intLiteral = true; }
- // Octal
- if (stream.match(/^0o[0-7]+/i)) { intLiteral = true; }
- // Decimal
- if (stream.match(/^[1-9]\d*(e[\+\-]?\d+)?/)) {
- intLiteral = true;
- }
+ if (stream.match(/^0x[0-9a-f]+/i)) { numberLiteral = true; } // Hex
+ if (stream.match(/^0b[01]+/i)) { numberLiteral = true; } // Binary
+ if (stream.match(/^0o[0-7]+/i)) { numberLiteral = true; } // Octal
+ if (stream.match(/^[1-9]\d*(e[\+\-]?\d+)?/)) { numberLiteral = true; } // Decimal
// Zero by itself with no other piece of number.
- if (stream.match(/^0(?![\dx])/i)) { intLiteral = true; }
- if (intLiteral) {
+ if (stream.match(/^0(?![\dx])/i)) { numberLiteral = true; }
+ if (numberLiteral) {
// Integer literals may be "long"
stream.match(imMatcher);
state.leavingExpr = true;
@@ -194,6 +183,12 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
return 'operator';
}
+ // Handle Chars
+ if (stream.match(/^'/)) {
+ state.tokenize = tokenChar;
+ return state.tokenize(stream, state);
+ }
+
// Handle Strings
if (stream.match(stringPrefixes)) {
state.tokenize = tokenStringFactory(stream.current());
@@ -269,7 +264,7 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
// over two or more lines.
if (stream.match(/^$/g, false)) {
stream.backUp(state.charsAdvanced);
- while (state.scopes.length > state.firstParenPos + 1)
+ while (state.scopes.length > state.firstParenPos)
state.scopes.pop();
state.firstParenPos = -1;
state.charsAdvanced = 0;
@@ -279,33 +274,65 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
return callOrDef(stream, state);
}
+ function tokenComment(stream, state) {
+ if (stream.match(/^#=/)) {
+ state.weakScopes++;
+ }
+ if (!stream.match(/.*?(?=(#=|=#))/)) {
+ stream.skipToEnd();
+ }
+ if (stream.match(/^=#/)) {
+ state.weakScopes--;
+ if (state.weakScopes == 0)
+ state.tokenize = tokenBase;
+ }
+ return 'comment';
+ }
+
+ function tokenChar(stream, state) {
+ var isChar = false, match;
+ if (stream.match(chars)) {
+ isChar = true;
+ } else if (match = stream.match(/\\u([a-f0-9]{1,4})(?=')/i)) {
+ var value = parseInt(match[1], 16);
+ if (value <= 55295 || value >= 57344) { // (U+0,U+D7FF), (U+E000,U+FFFF)
+ isChar = true;
+ stream.next();
+ }
+ } else if (match = stream.match(/\\U([A-Fa-f0-9]{5,8})(?=')/)) {
+ var value = parseInt(match[1], 16);
+ if (value <= 1114111) { // U+10FFFF
+ isChar = true;
+ stream.next();
+ }
+ }
+ if (isChar) {
+ state.leavingExpr = true;
+ state.tokenize = tokenBase;
+ return 'string';
+ }
+ if (!stream.match(/^[^']+(?=')/)) { stream.skipToEnd(); }
+ if (stream.match(/^'/)) { state.tokenize = tokenBase; }
+ return ERRORCLASS;
+ }
+
function tokenStringFactory(delimiter) {
while ('bruv'.indexOf(delimiter.charAt(0).toLowerCase()) >= 0) {
delimiter = delimiter.substr(1);
}
- var singleline = delimiter == "'";
var OUTCLASS = 'string';
function tokenString(stream, state) {
while (!stream.eol()) {
- stream.eatWhile(/[^'"\\]/);
+ stream.eatWhile(/[^"\\]/);
if (stream.eat('\\')) {
stream.next();
- if (singleline && stream.eol()) {
- return OUTCLASS;
- }
} else if (stream.match(delimiter)) {
state.tokenize = tokenBase;
+ state.leavingExpr = true;
return OUTCLASS;
} else {
- stream.eat(/['"]/);
- }
- }
- if (singleline) {
- if (parserConf.singleLineStringErrors) {
- return ERRORCLASS;
- } else {
- state.tokenize = tokenBase;
+ stream.eat(/["]/);
}
}
return OUTCLASS;
@@ -319,6 +346,7 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
return {
tokenize: tokenBase,
scopes: [],
+ weakScopes: 0,
lastToken: null,
leavingExpr: false,
isDefinition: false,
@@ -345,15 +373,15 @@ CodeMirror.defineMode("julia", function(_conf, parserConf) {
indent: function(state, textAfter) {
var delta = 0;
- if (textAfter == "end" || textAfter == "]" || textAfter == "}" || textAfter == "else" || textAfter == "elseif" || textAfter == "catch" || textAfter == "finally") {
+ if (textAfter == "]" || textAfter == ")" || textAfter == "end" || textAfter == "else" || textAfter == "elseif" || textAfter == "catch" || textAfter == "finally") {
delta = -1;
}
return (state.scopes.length + delta) * _conf.indentUnit;
},
+ electricInput: /(end|else(if)?|catch|finally)$/,
lineComment: "#",
- fold: "indent",
- electricChars: "edlsifyh]}"
+ fold: "indent"
};
return external;
});
diff --git a/public/vendor/codemirror/mode/markdown/markdown.js b/public/vendor/codemirror/mode/markdown/markdown.js
index 415a6c78..8bd3cc7a 100644
--- a/public/vendor/codemirror/mode/markdown/markdown.js
+++ b/public/vendor/codemirror/mode/markdown/markdown.js
@@ -88,7 +88,7 @@ CodeMirror.defineMode("markdown", function(cmCfg, modeCfg) {
, setextHeaderRE = /^ *(?:\={1,}|-{1,})\s*$/
, textRE = /^[^#!\[\]*_\\<>` "'(~]+/
, fencedCodeRE = new RegExp("^(" + (modeCfg.fencedCodeBlocks === true ? "~~~+|```+" : modeCfg.fencedCodeBlocks) +
- ")[ \\t]*([\\w+#]*)");
+ ")[ \\t]*([\\w+#\-]*)");
function switchInline(stream, state, f) {
state.f = state.inline = f;
@@ -804,4 +804,4 @@ CodeMirror.defineMode("markdown", function(cmCfg, modeCfg) {
CodeMirror.defineMIME("text/x-markdown", "markdown");
-});
\ No newline at end of file
+});
diff --git a/public/vendor/codemirror/mode/markdown/test.js b/public/vendor/codemirror/mode/markdown/test.js
index 6d7829fa..e2b3a815 100644
--- a/public/vendor/codemirror/mode/markdown/test.js
+++ b/public/vendor/codemirror/mode/markdown/test.js
@@ -452,6 +452,18 @@
"",
"hello");
+ MT("listCommonMarkIndentationCode",
+ "[variable-2 * Code blocks also affect]",
+ " [variable-3 * The next level starts where the contents start.]",
+ " [variable-3 * Anything less than that will keep the item on the same level.]",
+ " [variable-3 * Each list item can indent the first level further and further.]",
+ " [variable-3 * For the most part, this makes sense while writing a list.]",
+ " [keyword * This means two items with same indentation can be different levels.]",
+ " [keyword * Each level has an indent requirement that can change between items.]",
+ " [keyword * A list item that meets this will be part of the next level.]",
+ " [variable-3 * Otherwise, it will be part of the level where it does meet this.]",
+ " [variable-2 * World]");
+
// Blockquote
MT("blockquote",
"[variable-2 * foo]",
@@ -635,7 +647,7 @@
MT("linkReferenceEmStrong",
"[link [[][link&strong **][link&em&strong *foo**][link&em *][link ]]][string&url [[bar]]] hello");
- // Reference-style links with optional space separator (per docuentation)
+ // Reference-style links with optional space separator (per documentation)
// "You can optionally use a space to separate the sets of brackets"
MT("linkReferenceSpace",
"[link [[foo]]] [string&url [[bar]]] hello");
@@ -671,7 +683,7 @@
MT("labelTitleSingleQuotes",
"[link [[foo]]:] [string&url http://example.com/ 'bar']");
- MT("labelTitleParenthese",
+ MT("labelTitleParentheses",
"[link [[foo]]:] [string&url http://example.com/ (bar)]");
MT("labelTitleInvalid",
@@ -688,7 +700,7 @@
"[link [[foo]]:] [string&url http://example.com/]",
"[string 'bar'] hello");
- MT("labelTitleNextParenthese",
+ MT("labelTitleNextParentheses",
"[link [[foo]]:] [string&url http://example.com/]",
"[string (bar)] hello");
diff --git a/public/vendor/codemirror/mode/mathematica/mathematica.js b/public/vendor/codemirror/mode/mathematica/mathematica.js
index 5ae6f55c..d6977088 100644
--- a/public/vendor/codemirror/mode/mathematica/mathematica.js
+++ b/public/vendor/codemirror/mode/mathematica/mathematica.js
@@ -126,6 +126,7 @@ CodeMirror.defineMode('mathematica', function(_config, _parserConfig) {
}
// everything else is an error
+ stream.next(); // advance the stream.
return 'error';
}
diff --git a/public/vendor/codemirror/mode/meta.js b/public/vendor/codemirror/mode/meta.js
index 49520717..6980593f 100644
--- a/public/vendor/codemirror/mode/meta.js
+++ b/public/vendor/codemirror/mode/meta.js
@@ -21,7 +21,8 @@
{name: "C++", mime: "text/x-c++src", mode: "clike", ext: ["cpp", "c++", "cc", "cxx", "hpp", "h++", "hh", "hxx"], alias: ["cpp"]},
{name: "Cobol", mime: "text/x-cobol", mode: "cobol", ext: ["cob", "cpy"]},
{name: "C#", mime: "text/x-csharp", mode: "clike", ext: ["cs"], alias: ["csharp"]},
- {name: "Clojure", mime: "text/x-clojure", mode: "clojure", ext: ["clj"]},
+ {name: "Clojure", mime: "text/x-clojure", mode: "clojure", ext: ["clj", "cljc", "cljx"]},
+ {name: "ClojureScript", mime: "text/x-clojurescript", mode: "clojure", ext: ["cljs"]},
{name: "Closure Stylesheets (GSS)", mime: "text/x-gss", mode: "css", ext: ["gss"]},
{name: "CMake", mime: "text/x-cmake", mode: "cmake", ext: ["cmake", "cmake.in"], file: /^CMakeLists.txt$/},
{name: "CoffeeScript", mime: "text/x-coffeescript", mode: "coffeescript", ext: ["coffee"], alias: ["coffee", "coffee-script"]},
@@ -40,12 +41,14 @@
{name: "Dylan", mime: "text/x-dylan", mode: "dylan", ext: ["dylan", "dyl", "intr"]},
{name: "EBNF", mime: "text/x-ebnf", mode: "ebnf"},
{name: "ECL", mime: "text/x-ecl", mode: "ecl", ext: ["ecl"]},
+ {name: "edn", mime: "application/edn", mode: "clojure", ext: ["edn"]},
{name: "Eiffel", mime: "text/x-eiffel", mode: "eiffel", ext: ["e"]},
{name: "Elm", mime: "text/x-elm", mode: "elm", ext: ["elm"]},
{name: "Embedded Javascript", mime: "application/x-ejs", mode: "htmlembedded", ext: ["ejs"]},
{name: "Embedded Ruby", mime: "application/x-erb", mode: "htmlembedded", ext: ["erb"]},
{name: "Erlang", mime: "text/x-erlang", mode: "erlang", ext: ["erl"]},
{name: "Factor", mime: "text/x-factor", mode: "factor", ext: ["factor"]},
+ {name: "FCL", mime: "text/x-fcl", mode: "fcl"},
{name: "Forth", mime: "text/x-forth", mode: "forth", ext: ["forth", "fth", "4th"]},
{name: "Fortran", mime: "text/x-fortran", mode: "fortran", ext: ["f", "for", "f77", "f90"]},
{name: "F#", mime: "text/x-fsharp", mode: "mllike", ext: ["fs"], alias: ["fsharp"]},
@@ -53,7 +56,7 @@
{name: "Gherkin", mime: "text/x-feature", mode: "gherkin", ext: ["feature"]},
{name: "GitHub Flavored Markdown", mime: "text/x-gfm", mode: "gfm", file: /^(readme|contributing|history).md$/i},
{name: "Go", mime: "text/x-go", mode: "go", ext: ["go"]},
- {name: "Groovy", mime: "text/x-groovy", mode: "groovy", ext: ["groovy"]},
+ {name: "Groovy", mime: "text/x-groovy", mode: "groovy", ext: ["groovy", "gradle"]},
{name: "HAML", mime: "text/x-haml", mode: "haml", ext: ["haml"]},
{name: "Haskell", mime: "text/x-haskell", mode: "haskell", ext: ["hs"]},
{name: "Haskell (Literate)", mime: "text/x-literate-haskell", mode: "haskell-literate", ext: ["lhs"]},
@@ -82,13 +85,13 @@
{name: "MariaDB SQL", mime: "text/x-mariadb", mode: "sql"},
{name: "Mathematica", mime: "text/x-mathematica", mode: "mathematica", ext: ["m", "nb"]},
{name: "Modelica", mime: "text/x-modelica", mode: "modelica", ext: ["mo"]},
- {name: "MUMPS", mime: "text/x-mumps", mode: "mumps"},
+ {name: "MUMPS", mime: "text/x-mumps", mode: "mumps", ext: ["mps"]},
{name: "MS SQL", mime: "text/x-mssql", mode: "sql"},
{name: "MySQL", mime: "text/x-mysql", mode: "sql"},
{name: "Nginx", mime: "text/x-nginx-conf", mode: "nginx", file: /nginx.*\.conf$/i},
{name: "NSIS", mime: "text/x-nsis", mode: "nsis", ext: ["nsh", "nsi"]},
{name: "NTriples", mime: "text/n-triples", mode: "ntriples", ext: ["nt"]},
- {name: "Objective C", mime: "text/x-objectivec", mode: "clike", ext: ["m", "mm"]},
+ {name: "Objective C", mime: "text/x-objectivec", mode: "clike", ext: ["m", "mm"], alias: ["objective-c", "objc"]},
{name: "OCaml", mime: "text/x-ocaml", mode: "mllike", ext: ["ml", "mli", "mll", "mly"]},
{name: "Octave", mime: "text/x-octave", mode: "octave", ext: ["m"]},
{name: "Oz", mime: "text/x-oz", mode: "oz", ext: ["oz"]},
@@ -99,8 +102,10 @@
{name: "Pig", mime: "text/x-pig", mode: "pig", ext: ["pig"]},
{name: "Plain Text", mime: "text/plain", mode: "null", ext: ["txt", "text", "conf", "def", "list", "log"]},
{name: "PLSQL", mime: "text/x-plsql", mode: "sql", ext: ["pls"]},
+ {name: "PowerShell", mime: "application/x-powershell", mode: "powershell", ext: ["ps1", "psd1", "psm1"]},
{name: "Properties files", mime: "text/x-properties", mode: "properties", ext: ["properties", "ini", "in"], alias: ["ini", "properties"]},
- {name: "Python", mime: "text/x-python", mode: "python", ext: ["py", "pyw"]},
+ {name: "ProtoBuf", mime: "text/x-protobuf", mode: "protobuf", ext: ["proto"]},
+ {name: "Python", mime: "text/x-python", mode: "python", ext: ["BUILD", "bzl", "py", "pyw"], file: /^(BUCK|BUILD)$/},
{name: "Puppet", mime: "text/x-puppet", mode: "puppet", ext: ["pp"]},
{name: "Q", mime: "text/x-q", mode: "q", ext: ["q"]},
{name: "R", mime: "text/x-rsrc", mode: "r", ext: ["r"], alias: ["rscript"]},
@@ -109,6 +114,7 @@
{name: "RPM Spec", mime: "text/x-rpm-spec", mode: "rpm", ext: ["spec"]},
{name: "Ruby", mime: "text/x-ruby", mode: "ruby", ext: ["rb"], alias: ["jruby", "macruby", "rake", "rb", "rbx"]},
{name: "Rust", mime: "text/x-rustsrc", mode: "rust", ext: ["rs"]},
+ {name: "SAS", mime: "text/x-sas", mode: "sas", ext: ["sas"]},
{name: "Sass", mime: "text/x-sass", mode: "sass", ext: ["sass"]},
{name: "Scala", mime: "text/x-scala", mode: "clike", ext: ["scala"]},
{name: "Scheme", mime: "text/x-scheme", mode: "scheme", ext: ["scm", "ss"]},
@@ -125,7 +131,6 @@
{name: "SQL", mime: "text/x-sql", mode: "sql", ext: ["sql"]},
{name: "Squirrel", mime: "text/x-squirrel", mode: "clike", ext: ["nut"]},
{name: "Swift", mime: "text/x-swift", mode: "swift", ext: ["swift"]},
- {name: "MariaDB", mime: "text/x-mariadb", mode: "sql"},
{name: "sTeX", mime: "text/x-stex", mode: "stex"},
{name: "LaTeX", mime: "text/x-latex", mode: "stex", ext: ["text", "ltx"], alias: ["tex"]},
{name: "SystemVerilog", mime: "text/x-systemverilog", mode: "verilog", ext: ["v"]},
@@ -135,12 +140,13 @@
{name: "Tiki wiki", mime: "text/tiki", mode: "tiki"},
{name: "TOML", mime: "text/x-toml", mode: "toml", ext: ["toml"]},
{name: "Tornado", mime: "text/x-tornado", mode: "tornado"},
- {name: "troff", mime: "troff", mode: "troff", ext: ["1", "2", "3", "4", "5", "6", "7", "8", "9"]},
+ {name: "troff", mime: "text/troff", mode: "troff", ext: ["1", "2", "3", "4", "5", "6", "7", "8", "9"]},
{name: "TTCN", mime: "text/x-ttcn", mode: "ttcn", ext: ["ttcn", "ttcn3", "ttcnpp"]},
{name: "TTCN_CFG", mime: "text/x-ttcn-cfg", mode: "ttcn-cfg", ext: ["cfg"]},
{name: "Turtle", mime: "text/turtle", mode: "turtle", ext: ["ttl"]},
{name: "TypeScript", mime: "application/typescript", mode: "javascript", ext: ["ts"], alias: ["ts"]},
{name: "Twig", mime: "text/x-twig", mode: "twig"},
+ {name: "Web IDL", mime: "text/x-webidl", mode: "webidl", ext: ["webidl"]},
{name: "VB.NET", mime: "text/x-vb", mode: "vb", ext: ["vb"]},
{name: "VBScript", mime: "text/vbscript", mode: "vbscript", ext: ["vbs"]},
{name: "Velocity", mime: "text/velocity", mode: "velocity", ext: ["vtl"]},
@@ -148,6 +154,7 @@
{name: "VHDL", mime: "text/x-vhdl", mode: "vhdl", ext: ["vhd", "vhdl"]},
{name: "XML", mimes: ["application/xml", "text/xml"], mode: "xml", ext: ["xml", "xsl", "xsd"], alias: ["rss", "wsdl", "xsd"]},
{name: "XQuery", mime: "application/xquery", mode: "xquery", ext: ["xy", "xquery"]},
+ {name: "Yacas", mime: "text/x-yacas", mode: "yacas", ext: ["ys"]},
{name: "YAML", mime: "text/x-yaml", mode: "yaml", ext: ["yaml", "yml"], alias: ["yml"]},
{name: "Z80", mime: "text/x-z80", mode: "z80", ext: ["z80"]},
{name: "mscgen", mime: "text/x-mscgen", mode: "mscgen", ext: ["mscgen", "mscin", "msc"]},
diff --git a/public/vendor/codemirror/mode/octave/index.html b/public/vendor/codemirror/mode/octave/index.html
index 79df5811..3490ee63 100644
--- a/public/vendor/codemirror/mode/octave/index.html
+++ b/public/vendor/codemirror/mode/octave/index.html
@@ -65,7 +65,7 @@ global persistent
%one line comment
%{ multi
-line commment %}
+line comment %}
+
+
+
+
+
+
+ PowerShell mode
+
+
+# Number Literals
+0 12345
+12kb 12mb 12gB 12Tb 12PB 12L 12D 12lkb 12dtb
+1.234 1.234e56 1. 1.e2 .2 .2e34
+1.2MB 1.kb .1dTb 1.e1gb
+0x1 0xabcdef 0x3tb 0xelmb
+
+# String Literals
+'Literal escaping'''
+'Literal $variable'
+"Escaping 1`""
+"Escaping 2"""
+"Escaped `$variable"
+"Text, $variable and more text"
+"Text, ${variable with spaces} and more text."
+"Text, $($expression + 3) and more text."
+"Text, $("interpolation $("inception")") and more text."
+
+@"
+Multiline
+string
+"@
+# --
+@"
+Multiline
+string with quotes "'
+"@
+# --
+@'
+Multiline literal
+string with quotes "'
+'@
+
+# Array and Hash literals
+@( 'a','b','c' )
+@{ 'key': 'value' }
+
+# Variables
+$Variable = 5
+$global:variable = 5
+${Variable with spaces} = 5
+
+# Operators
+= += -= *= /= %=
+++ -- .. -f * / % + -
+-not ! -bnot
+-split -isplit -csplit
+-join
+-is -isnot -as
+-eq -ieq -ceq -ne -ine -cne
+-gt -igt -cgt -ge -ige -cge
+-lt -ilt -clt -le -ile -cle
+-like -ilike -clike -notlike -inotlike -cnotlike
+-match -imatch -cmatch -notmatch -inotmatch -cnotmatch
+-contains -icontains -ccontains -notcontains -inotcontains -cnotcontains
+-replace -ireplace -creplace
+-band -bor -bxor
+-and -or -xor
+
+# Punctuation
+() [] {} , : ` = ; .
+
+# Keywords
+elseif begin function for foreach return else trap while do data dynamicparam
+until end break if throw param continue finally in switch exit filter from try
+process catch
+
+# Built-in variables
+$$ $? $^ $_
+$args $ConfirmPreference $ConsoleFileName $DebugPreference $Error
+$ErrorActionPreference $ErrorView $ExecutionContext $false $FormatEnumerationLimit
+$HOME $Host $input $MaximumAliasCount $MaximumDriveCount $MaximumErrorCount
+$MaximumFunctionCount $MaximumHistoryCount $MaximumVariableCount $MyInvocation
+$NestedPromptLevel $null $OutputEncoding $PID $PROFILE $ProgressPreference
+$PSBoundParameters $PSCommandPath $PSCulture $PSDefaultParameterValues
+$PSEmailServer $PSHOME $PSScriptRoot $PSSessionApplicationName
+$PSSessionConfigurationName $PSSessionOption $PSUICulture $PSVersionTable $PWD
+$ShellId $StackTrace $true $VerbosePreference $WarningPreference $WhatIfPreference
+$true $false $null
+
+# Built-in functions
+A:
+Add-Computer Add-Content Add-History Add-Member Add-PSSnapin Add-Type
+B:
+C:
+Checkpoint-Computer Clear-Content Clear-EventLog Clear-History Clear-Host Clear-Item
+Clear-ItemProperty Clear-Variable Compare-Object Complete-Transaction Connect-PSSession
+ConvertFrom-Csv ConvertFrom-Json ConvertFrom-SecureString ConvertFrom-StringData
+Convert-Path ConvertTo-Csv ConvertTo-Html ConvertTo-Json ConvertTo-SecureString
+ConvertTo-Xml Copy-Item Copy-ItemProperty
+D:
+Debug-Process Disable-ComputerRestore Disable-PSBreakpoint Disable-PSRemoting
+Disable-PSSessionConfiguration Disconnect-PSSession
+E:
+Enable-ComputerRestore Enable-PSBreakpoint Enable-PSRemoting Enable-PSSessionConfiguration
+Enter-PSSession Exit-PSSession Export-Alias Export-Clixml Export-Console Export-Counter
+Export-Csv Export-FormatData Export-ModuleMember Export-PSSession
+F:
+ForEach-Object Format-Custom Format-List Format-Table Format-Wide
+G:
+Get-Acl Get-Alias Get-AuthenticodeSignature Get-ChildItem Get-Command Get-ComputerRestorePoint
+Get-Content Get-ControlPanelItem Get-Counter Get-Credential Get-Culture Get-Date
+Get-Event Get-EventLog Get-EventSubscriber Get-ExecutionPolicy Get-FormatData Get-Help
+Get-History Get-Host Get-HotFix Get-Item Get-ItemProperty Get-Job Get-Location Get-Member
+Get-Module Get-PfxCertificate Get-Process Get-PSBreakpoint Get-PSCallStack Get-PSDrive
+Get-PSProvider Get-PSSession Get-PSSessionConfiguration Get-PSSnapin Get-Random Get-Service
+Get-TraceSource Get-Transaction Get-TypeData Get-UICulture Get-Unique Get-Variable Get-Verb
+Get-WinEvent Get-WmiObject Group-Object
+H:
+help
+I:
+Import-Alias Import-Clixml Import-Counter Import-Csv Import-LocalizedData Import-Module
+Import-PSSession ImportSystemModules Invoke-Command Invoke-Expression Invoke-History
+Invoke-Item Invoke-RestMethod Invoke-WebRequest Invoke-WmiMethod
+J:
+Join-Path
+K:
+L:
+Limit-EventLog
+M:
+Measure-Command Measure-Object mkdir more Move-Item Move-ItemProperty
+N:
+New-Alias New-Event New-EventLog New-Item New-ItemProperty New-Module New-ModuleManifest
+New-Object New-PSDrive New-PSSession New-PSSessionConfigurationFile New-PSSessionOption
+New-PSTransportOption New-Service New-TimeSpan New-Variable New-WebServiceProxy
+New-WinEvent
+O:
+oss Out-Default Out-File Out-GridView Out-Host Out-Null Out-Printer Out-String
+P:
+Pause Pop-Location prompt Push-Location
+Q:
+R:
+Read-Host Receive-Job Receive-PSSession Register-EngineEvent Register-ObjectEvent
+Register-PSSessionConfiguration Register-WmiEvent Remove-Computer Remove-Event
+Remove-EventLog Remove-Item Remove-ItemProperty Remove-Job Remove-Module
+Remove-PSBreakpoint Remove-PSDrive Remove-PSSession Remove-PSSnapin Remove-TypeData
+Remove-Variable Remove-WmiObject Rename-Computer Rename-Item Rename-ItemProperty
+Reset-ComputerMachinePassword Resolve-Path Restart-Computer Restart-Service
+Restore-Computer Resume-Job Resume-Service
+S:
+Save-Help Select-Object Select-String Select-Xml Send-MailMessage Set-Acl Set-Alias
+Set-AuthenticodeSignature Set-Content Set-Date Set-ExecutionPolicy Set-Item
+Set-ItemProperty Set-Location Set-PSBreakpoint Set-PSDebug
+Set-PSSessionConfiguration Set-Service Set-StrictMode Set-TraceSource Set-Variable
+Set-WmiInstance Show-Command Show-ControlPanelItem Show-EventLog Sort-Object
+Split-Path Start-Job Start-Process Start-Service Start-Sleep Start-Transaction
+Start-Transcript Stop-Computer Stop-Job Stop-Process Stop-Service Stop-Transcript
+Suspend-Job Suspend-Service
+T:
+TabExpansion2 Tee-Object Test-ComputerSecureChannel Test-Connection
+Test-ModuleManifest Test-Path Test-PSSessionConfigurationFile Trace-Command
+U:
+Unblock-File Undo-Transaction Unregister-Event Unregister-PSSessionConfiguration
+Update-FormatData Update-Help Update-List Update-TypeData Use-Transaction
+V:
+W:
+Wait-Event Wait-Job Wait-Process Where-Object Write-Debug Write-Error Write-EventLog
+Write-Host Write-Output Write-Progress Write-Verbose Write-Warning
+X:
+Y:
+Z:
+
+
+ MIME types defined: application/x-powershell
.
+
+
+
diff --git a/public/vendor/codemirror/mode/django/django.js b/public/vendor/codemirror/mode/django/django.js
index eb8d6591..7b4ef3b5 100644
--- a/public/vendor/codemirror/mode/django/django.js
+++ b/public/vendor/codemirror/mode/django/django.js
@@ -61,16 +61,16 @@
// Ignore completely any stream series that do not match the
// Django template opening tags.
- while (stream.next() != null && !stream.match("{{", false) && !stream.match("{%", false)) {}
+ while (stream.next() != null && !stream.match(/\{[{%#]/, false)) {}
return null;
}
// A string can be included in either single or double quotes (this is
// the delimeter). Mark everything as a string until the start delimeter
// occurs again.
- function inString (delimeter, previousTokenizer) {
+ function inString (delimiter, previousTokenizer) {
return function (stream, state) {
- if (!state.escapeNext && stream.eat(delimeter)) {
+ if (!state.escapeNext && stream.eat(delimiter)) {
state.tokenize = previousTokenizer;
} else {
if (state.escapeNext) {
@@ -80,7 +80,7 @@
var ch = stream.next();
// Take into account the backslash for escaping characters, such as
- // the string delimeter.
+ // the string delimiter.
if (ch == "\\") {
state.escapeNext = true;
}
@@ -100,7 +100,7 @@
return "null";
}
- // Dot folowed by a non-word character should be considered an error.
+ // Dot followed by a non-word character should be considered an error.
if (stream.match(/\.\W+/)) {
return "error";
} else if (stream.eat(".")) {
@@ -119,7 +119,7 @@
return "null";
}
- // Pipe folowed by a non-word character should be considered an error.
+ // Pipe followed by a non-word character should be considered an error.
if (stream.match(/\.\W+/)) {
return "error";
} else if (stream.eat("|")) {
@@ -199,7 +199,7 @@
return "null";
}
- // Dot folowed by a non-word character should be considered an error.
+ // Dot followed by a non-word character should be considered an error.
if (stream.match(/\.\W+/)) {
return "error";
} else if (stream.eat(".")) {
@@ -218,7 +218,7 @@
return "null";
}
- // Pipe folowed by a non-word character should be considered an error.
+ // Pipe followed by a non-word character should be considered an error.
if (stream.match(/\.\W+/)) {
return "error";
} else if (stream.eat("|")) {
@@ -317,9 +317,8 @@
// Mark everything as comment inside the tag and the tag itself.
function inComment (stream, state) {
- if (stream.match("#}")) {
- state.tokenize = tokenBase;
- }
+ if (stream.match(/^.*?#\}/)) state.tokenize = tokenBase
+ else stream.skipToEnd()
return "comment";
}
@@ -61,16 +61,16 @@
}
// A string can be included in either single or double quotes (this is
- // the delimeter). Mark everything as a string until the start delimeter
+ // the delimiter). Mark everything as a string until the start delimiter
// occurs again.